@@ -12,7 +12,7 @@
 import threading
 
 
-class LockHelper(object):
+class RWLock(object):
     def __init__(self):
         self.rlock = threading.Lock()
         self.wlock = threading.Lock()
